==> zio-aws-swf_3-5.17.104.5-sources.jar: zio/aws/swf/model/ListClosedWorkflowExecutionsResponse.scala <==
package zio.aws.swf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.swf.model.primitives.PageToken
import scala.jdk.CollectionConverters.*
final case class ListClosedWorkflowExecutionsResponse(
    executionInfos: Iterable[zio.aws.swf.model.WorkflowExecutionInfo],
    nextPageToken: Option[PageToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.swf.model.ListClosedWorkflowExecutionsResponse = {
    import ListClosedWorkflowExecutionsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.swf.model.ListClosedWorkflowExecutionsResponse
      .builder()
      .executionInfos(executionInfos.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        nextPageToken.map(value => PageToken.unwrap(value): java.lang.String)
      )(_.nextPageToken)
      .build()
  }
  def asReadOnly
      : zio.aws.swf.model.ListClosedWorkflowExecutionsResponse.ReadOnly =
    zio.aws.swf.model.ListClosedWorkflowExecutionsResponse.wrap(buildAwsValue())
}
object ListClosedWorkflowExecutionsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.swf.model.ListClosedWorkflowExecutionsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.swf.model.ListClosedWorkflowExecutionsResponse =
      zio.aws.swf.model.ListClosedWorkflowExecutionsResponse(
        executionInfos.map { item =>
          item.asEditable
        },
        nextPageToken.map(value => value)
      )
    def executionInfos: List[zio.aws.swf.model.WorkflowExecutionInfo.ReadOnly]
    def nextPageToken: Option[PageToken]
    def getExecutionInfos: ZIO[Any, Nothing, List[
      zio.aws.swf.model.WorkflowExecutionInfo.ReadOnly
    ]] = ZIO.succeed(executionInfos)
    def getNextPageToken: ZIO[Any, AwsError, PageToken] =
      AwsError.unwrapOptionField("nextPageToken", nextPageToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.swf.model.ListClosedWorkflowExecutionsResponse
  ) extends zio.aws.swf.model.ListClosedWorkflowExecutionsResponse.ReadOnly {
    override val executionInfos
        : List[zio.aws.swf.model.WorkflowExecutionInfo.ReadOnly] = impl
      .executionInfos()
      .asScala
      .map { item =>
        zio.aws.swf.model.WorkflowExecutionInfo.wrap(item)
      }
      .toList
    override val nextPageToken: Option[PageToken] = scala
      .Option(impl.nextPageToken())
      .map(value => zio.aws.swf.model.primitives.PageToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.swf.model.ListClosedWorkflowExecutionsResponse
  ): zio.aws.swf.model.ListClosedWorkflowExecutionsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-swf_3-5.19.8.1-sources.jar: zio/aws/swf/model/ListClosedWorkflowExecutionsResponse.scala <==
package zio.aws.swf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.swf.model.primitives.PageToken
import scala.jdk.CollectionConverters.*
final case class ListClosedWorkflowExecutionsResponse(
    executionInfos: Iterable[zio.aws.swf.model.WorkflowExecutionInfo],
    nextPageToken: Optional[PageToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.swf.model.ListClosedWorkflowExecutionsResponse = {
    import ListClosedWorkflowExecutionsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.swf.model.ListClosedWorkflowExecutionsResponse
      .builder()
      .executionInfos(executionInfos.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        nextPageToken.map(value => PageToken.unwrap(value): java.lang.String)
      )(_.nextPageToken)
      .build()
  }
  def asReadOnly
      : zio.aws.swf.model.ListClosedWorkflowExecutionsResponse.ReadOnly =
    zio.aws.swf.model.ListClosedWorkflowExecutionsResponse.wrap(buildAwsValue())
}
object ListClosedWorkflowExecutionsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.swf.model.ListClosedWorkflowExecutionsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.swf.model.ListClosedWorkflowExecutionsResponse =
      zio.aws.swf.model.ListClosedWorkflowExecutionsResponse(
        executionInfos.map { item =>
          item.asEditable
        },
        nextPageToken.map(value => value)
      )
    def executionInfos: List[zio.aws.swf.model.WorkflowExecutionInfo.ReadOnly]
    def nextPageToken: Optional[PageToken]
    def getExecutionInfos: ZIO[Any, Nothing, List[
      zio.aws.swf.model.WorkflowExecutionInfo.ReadOnly
    ]] = ZIO.succeed(executionInfos)
    def getNextPageToken: ZIO[Any, AwsError, PageToken] =
      AwsError.unwrapOptionField("nextPageToken", nextPageToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.swf.model.ListClosedWorkflowExecutionsResponse
  ) extends zio.aws.swf.model.ListClosedWorkflowExecutionsResponse.ReadOnly {
    override val executionInfos
        : List[zio.aws.swf.model.WorkflowExecutionInfo.ReadOnly] = impl
      .executionInfos()
      .asScala
      .map { item =>
        zio.aws.swf.model.WorkflowExecutionInfo.wrap(item)
      }
      .toList
    override val nextPageToken: Optional[PageToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextPageToken())
      .map(value => zio.aws.swf.model.primitives.PageToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.swf.model.ListClosedWorkflowExecutionsResponse
  ): zio.aws.swf.model.ListClosedWorkflowExecutionsResponse.ReadOnly =
    new Wrapper(impl)
}
